pub enum CommandSender {
Player(Arc<Player>),
Console,
Rcon,
}Expand description
The sender of a command.
Variants
Player(Arc<Player>)
The command was sent by a player via the chat.
Console
The command was sent via the server’s console.
Rcon
The command was sent via Rcon.
Implementations
Sourceimpl CommandSender
impl CommandSender
pub(crate) fn key(&self) -> CommandSenderKey
Sourcepub const fn get_player(&self) -> Option<&Arc<Player>>
pub const fn get_player(&self) -> Option<&Arc<Player>>
Returns the player if the sender is a player.
Sourcepub fn send_message(&self, text: &TextComponent)
pub fn send_message(&self, text: &TextComponent)
Sends a system message to the command sender.